==> haskell-deepseq-generics-0.2.0.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deepseq-generics
version: 0.2.0.0
id: deepseq-generics-0.2.0.0-hP7tp3Chb8IodVRJfE3Qa
key: deepseq-generics-0.2.0.0-hP7tp3Chb8IodVRJfE3Qa
license: BSD3
copyright: 2012, Herbert Valerio Riedel
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/deepseq-generics
synopsis: GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.
    .
    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).
    .
    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.
    .
    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.
category: Control
author: Herbert Valerio Riedel
exposed: True
indefinite: False
exposed-modules:
    Control.DeepSeq.Generics
abi: 41d0c0e5372863a46e8fd6816d13901f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/deepseq-generics-0.2.0.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/deepseq-generics-0.2.0.0
hs-libraries: HSdeepseq-generics-0.2.0.0-hP7tp3Chb8IodVRJfE3Qa
depends:
    base-4.10.0.0 ghc-prim-0.5.1.0 deepseq-1.4.3.0
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
haddock-interfaces: /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock
haddock-html: /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deepseq-generics-0.2.0.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deepseq-generics
version: 0.2.0.0
id: deepseq-generics-0.2.0.0-G98MeMA7TbADTNFPYlzRtE
key: deepseq-generics-0.2.0.0-G98MeMA7TbADTNFPYlzRtE
license: BSD3
copyright: 2012, Herbert Valerio Riedel
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/deepseq-generics
synopsis: GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.
    .
    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).
    .
    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.
    .
    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.
category: Control
author: Herbert Valerio Riedel
exposed: True
indefinite: False
exposed-modules:
    Control.DeepSeq.Generics
abi: a14a338b0c35eed538dc96a6c1aab47e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/deepseq-generics-0.2.0.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/deepseq-generics-0.2.0.0
hs-libraries: HSdeepseq-generics-0.2.0.0-G98MeMA7TbADTNFPYlzRtE
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock
haddock-html: /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
